@@ -29,13 +29,16 @@ class BuiltInProvider(ITestProvider):
     """
 
     _builtin_tests = [
+        'bluetooth-enablement',
         'bootchart',
         'insanity',
         'firefox',
         'glmemperf',
         'gmpbench',
         'gtkperf',
+        'leb-basic-graphics',
         'ltp',
+        'lttng',
         'peacekeeper',
         'perf',
         'posixtestsuite',
@@ -46,6 +49,7 @@ class BuiltInProvider(ITestProvider):
         'tiobench',
         'x11perf',
         'xrestop',
+        'wifi-enablement',
     ]
 
     def __init__(self, config):
