@@ -14,10 +14,14 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
-   This script automates the automate installation, execution, and
-   results parsing for the GMPbench test suite.
-   The GMPbench test Suite is an open source test suite with the goal of
-   comparing different processors performance against eachother.
+This script automates the automate installation, execution, and
+results parsing for the GMPbench test suite.
+The GMPbench test Suite is an open source test suite with the goal of
+comparing different processors performance against eachother.
+
+**URL:** http://gmplib.org/gmpbench.html
+
+**Default Options:** None
 
 """
 
