@@ -18,14 +18,15 @@ from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
-
-RUNSTEPS = ['smem -w | tail -n 3']
+DEFAULT_OPTIONS = ""
+RUNSTEPS = ['smem -w $(OPTIONS) | tail -n 3']
 PATTERN = "^(?P<test_case_id>(\w+\s)+)\s\s+(?P<measurement>\d+)"
 DEPS = ['smem']
 
+
 smeminst = TestInstaller(deps=DEPS)
-smemrun = TestRunner(RUNSTEPS)
+smemrun = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
 smemparser = TestParser(PATTERN,
                appendall={'units':'KB', 'result':'pass'})
-testobj = Test(testname="smem", installer=smeminst,
+testobj = Test(test_id="smem", installer=smeminst,
                                   runner=smemrun, parser=smemparser)
